/*	block.c	*/

#include "block.h"

int initBlocks(Block * blocks, Game_Theme * theme) {
	int col, row, y = 480 - 142, index;
	int MAX_COL = (theme->block_image_count < 3) ?
		theme->block_image_count : 3; 
	// Seed the random number generator
	srand(time(NULL));
	
	// Randomize the initial colour
	int block_colour = rand() % MAX_COL;
	
	for (row = 0; row < 15; row++) {
		for (col = 0; col < 12; col++) {
			index = (row * 12) + col;
			blocks[index].x = 16 + (col * 32);
			blocks[index].y = y;
			blocks[index].image = block_colour;
			blocks[index].visible = 1;
			blocks[index].marked = 0;
			
			// Determine if the block colour will change
			int chance = rand() % 3;
			if (chance == 0) block_colour = rand() % MAX_COL;
		}
		y += 32;
	}
	
	return MAX_COL;
}

int moveBlocksUp(Block * blocks, int * block_colour, int * move_timer) {
	int max_height = 0, i;
	if (blocks[0].y <= 18) {
		for (i = 0; i < 12; i++) {
			if (blocks[i].visible) {
				max_height = 1;
				break;
			}
		}
				
		if (!max_height) {
			for (i = 0; i < 12 * 14; i++) {
				blocks[i].y = blocks[i+12].y;
				blocks[i].visible = blocks[i + 12].visible;
				blocks[i].image = blocks[i + 12].image;
			}
			for (i = 168; i < 180; i++) {
				blocks[i].y = blocks[i - 12].y + 32;
				blocks[i].visible = 1;
				blocks[i].image = *block_colour;
				
				// Determine if the block colour will change
				int chance = rand() % 3;
				if (chance == 0) *block_colour = rand() % 3;
			}
		}
	}
			
	if (!max_height && (*move_timer < 0 && *move_timer >= -8)) {
		// The blocks haven't reached the top row, move them all up one.
		for (i = 0; i < 12 * 15; i++) {
			blocks[i].y -= 4;
		}
	}
	
	return max_height;
}

void matchBlock(int index, Block * blocks, int colour, int * marked_count) {
	if (!blocks[index].visible || blocks[index].marked) return; 
	if ((blocks[index].image == colour && blocks[index].y < 464) ||
		colour < 0) {
		if (colour < 0) colour = blocks[index].image;
		blocks[index].marked = 1;
		*marked_count = *marked_count + 1;
		const int column = index % 12;
		const int row = index / 12;
		if (column > 0) {
			matchBlock(index - 1, blocks, colour, marked_count);
		} // Checks if block to left is same colour
		if (column < 11) {
			matchBlock(index + 1, blocks, colour, marked_count);
		} // Checks if block to right is same colour
		if (row > 0) {
			matchBlock(index - 12, blocks, colour, marked_count);
		} // Checks if block above is same colour
		if (row < 14) {
			matchBlock(index + 12, blocks, colour, marked_count);
		} // Checks is block below is same colour
	}
}

void dropBlocksDown(Block * blocks) {
	int i, j;
	for (i = 0; i < 156; i++) {
		if (!blocks[i+12].visible) {
			for (j = i; j >= 0; j -= 12) {
				if (blocks[j].visible) blocks[j].y += 8;
			}
			if (blocks[i].y >= blocks[i+12].y) {
				for (j = i; j >= 0; j -= 12) {
					blocks[j+12].image = blocks[j].image;
					blocks[j+12].visible = blocks[j].visible;
					blocks[j].visible = 0;
					blocks[j].y = blocks[j+12].y - 32;
				}
			}
		}
	}
}
