/*	theme.h	*/

#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>
#include <SDL/SDL_image.h>
#include <SDL/SDL_gfxPrimitives.h>
#include <SDL/SDL_mixer.h>

#ifndef	COM_PLUS_MEVANSPN_BB_THEMES
#define COM_PLUS_MEVANSPN_BB_THEMES

typedef struct {
	SDL_Surface * background;		// Background image used for window
	SDL_Surface ** block_images;	// Array of block image surfaces.
	SDL_Surface *** exploding_images;	// Array of images to holding block segments used in explosions.
	int block_image_count;			// Number of block image surfaces
	SDL_Surface * score_surface_bg;	// Background image to place behind the score.
	TTF_Font * value_font;			// Font used for score and other variable values.
	SDL_Color * value_colours;		// 2 values, foreground and background.
	TTF_Font * label_font;			// Font used for labels.
	SDL_Color * label_colours;		// 2 values, foreground and background.
	Mix_Music * game_music;			// Music used in game.
	Mix_Chunk * click_sound;		// Sound sample used to indicate click.
	Mix_Chunk * match_sound;		// Sound sample used as feedback for match.
	Mix_Chunk * alarm_sound;		// Sound sample used for stack warning.
	Mix_Chunk * powerup_sound;		// Sound sample used for power up.
	Mix_Chunk * gameover_sound;		// Sounds used to indicate game over.
} Game_Theme;

// Low level functions
void __setMaskRGBValue(SDL_Surface * surface);
SDL_Surface * __createTiledBackground(SDL_Surface * tile_surface, 
	const int width, const int height, const SDL_Surface * screen);

// Mid level functions
SDL_Surface * _loadGameBackground(const char * theme_folder, const SDL_Surface * screen);
TTF_Font * _loadFont(const char * theme_folder, const char * filename, const int size);
Mix_Music * _loadMusic(const char * theme_folder, const char * filename);
Mix_Chunk * _loadSample(const char * theme_folder, const char * filename);
void _loadBlocks(const char * theme_folder, SDL_Surface * screen, Game_Theme * theme);

// High level functions (user-scope)
Game_Theme * loadTheme(const char * theme_name, SDL_Surface * screen);
void freeTheme(Game_Theme * theme);

#endif
