/*	ui.h */

#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>

#ifndef COM_PLUS_MEVANSPN_BB_UI
#define COM_PLUS_MEVANSPN_BB_UI

typedef struct {
	char * label;			// Menu item label
	SDL_Surface * icon;		// Menu item icon
	SDL_Surface * rendered_label;	// Surface for pre-rendered label text.
	void (* action)();		// Pointer to executed function.
	void * next_menu_item;	// Pointer to next menu item (NULL if none)
	int x;					// Position of rendered label on menu.
} Menu_Item;

typedef struct {
	unsigned char background_colour[3];		// Required RGB background colour.
	SDL_Surface * background_image;			// Optional background image (replaces colour above)
	SDL_Surface * composite_surface;		// Surface to composite menu onto.
	unsigned short height;					// Height of the menu in pixels.
	unsigned short width;					// Width of the menu in pixels.
	int y;									// Vertical position of top of menu.
	TTF_Font * font;						// Font to use for text labels.
	int selection;							// Currently selected menu item index.
	Menu_Item * first_menu_item;			// Pointer to first Menu_Item
	int menu_item_count;					// Count of menu items.
	int min_x, max_x;						// Scrolling boundaries for rendered menu items.
	int scroll_dir;							// Direction to scroll menu items
	int scroll_steps;						// Used to control scroll distance
} Menu;

Menu_Item * createMenuItem(char * label, SDL_Surface * icon, void (*action)(),
	Menu_Item * previous_menu_item);
Menu_Item * freeMenuItem(Menu_Item * i);

Menu * createMenu(unsigned char red, unsigned char green, unsigned char blue,
	unsigned short width, unsigned short height, TTF_Font * font);
void freeMenu(Menu * m);
void addMenuItem(Menu * menu, char * label, SDL_Surface * icon, void (*action)());
Menu_Item * getMenuItem(Menu * menu, int index);
SDL_Surface * getRenderedMenu(Menu * menu, SDL_Surface * screen);
int scrollMenuItems(Menu * menu, int direction);
#endif
